@@ -546,6 +546,17 @@
 #       define WTF_CPU_BIG_ENDIAN 1
 #   endif
 
+#if (_WIN32_WCE >= 0x700)
+	// Windows Embedded Compact 7 is missing std::ptrdiff_t type and std::min and std::max.
+	// They are defined here to minimize the changes to JSCore
+	namespace std {
+		typedef ::ptrdiff_t ptrdiff_t;
+		template <class T> inline T max(const T& a, const T& b) { return (a > b) ? a : b; }
+		template <class T> inline T min(const T& a, const T& b) { return (a < b) ? a : b; }
+	}
+#endif
+
+// For localtime in Windows CE
 #   include <ce_time.h>
 #endif
 
@@ -1005,6 +1016,16 @@ on MinGW. See https://bugs.webkit.org/show_bug.cgi?id=29268 */
 #define ENABLE_ASSEMBLER_WX_EXCLUSIVE 0
 #endif
 
+/* Pick which allocator to use; we only need an executable allocator if the assembler is compiled in.
+   On x86-64 we use a single fixed mmap, on other platforms we mmap on demand. */
+#if ENABLE(ASSEMBLER)
+#if CPU(X86_64) && !COMPILER(MINGW64)
+#define ENABLE_EXECUTABLE_ALLOCATOR_FIXED 1
+#else
+#define ENABLE_EXECUTABLE_ALLOCATOR_DEMAND 1
+#endif
+#endif
+
 #if !defined(ENABLE_PAN_SCROLLING) && OS(WINDOWS)
 #define ENABLE_PAN_SCROLLING 1
 #endif
